@@ -31,7 +31,7 @@ from utilities.logging import (
 from utilities.text import unique_str
 from utilities.types import LogLevel
 from utilities.typing import get_args
-from utilities.whenever import get_now, to_local_plain
+from utilities.whenever import format_compact, get_now_local
 
 if TYPE_CHECKING:
     from collections.abc import Mapping
@@ -101,7 +101,7 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 1
-        assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.1\__.+?\.txt$", p.name))
 
         for _ in range(2):
             await sleep(1)
@@ -112,9 +112,7 @@ class TestComputeRolloverActions:
             actions.do()
             files = list(tmp_path.iterdir())
             assert len(files) == 1
-            assert any(
-                p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
-            )
+            assert any(p for p in files if search(r"^log\.1\__.+?__.+?\.txt$", p.name))
 
     async def test_multiple_backups(self, *, tmp_path: Path) -> None:
         tmp_path.joinpath("log.txt").touch()
@@ -125,7 +123,7 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 1
-        assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.1\__.+\.txt$", p.name))
 
         await sleep(1)
         tmp_path.joinpath("log.txt").touch()
@@ -135,10 +133,8 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 2
-        assert any(
-            p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
-        )
-        assert any(p for p in files if search(r"^log\.2\__[\dT]+\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.1\__.+?__.+?\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.2\__.+?\.txt$", p.name))
 
         await sleep(1)
         tmp_path.joinpath("log.txt").touch()
@@ -148,13 +144,9 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 3
-        assert any(
-            p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
-        )
-        assert any(
-            p for p in files if search(r"^log\.2\__[\dT]+__[\dT]+\.txt$", p.name)
-        )
-        assert all(p for p in files if search(r"^log\.3\__[\dT]+\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.1\__.+?__.+?\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.2\__.+?__.+?\.txt$", p.name))
+        assert all(p for p in files if search(r"^log\.3\__.+?\.txt$", p.name))
 
         for _ in range(2):
             await sleep(1)
@@ -165,15 +157,9 @@ class TestComputeRolloverActions:
             actions.do()
             files = list(tmp_path.iterdir())
             assert len(files) == 3
-            assert any(
-                p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(
-                p for p in files if search(r"^log\.2\__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert all(
-                p for p in files if search(r"^log\.3\__[\dT]+__[\dT]+\.txt$", p.name)
-            )
+            assert any(p for p in files if search(r"^log\.1\__.+?__.+?\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.2\__.+?__.+?\.txt$", p.name))
+            assert all(p for p in files if search(r"^log\.3\__.+?__.+?\.txt$", p.name))
 
     async def test_deleting_old_files(self, *, tmp_path: Path) -> None:
         tmp_path.joinpath("log.txt").touch()
@@ -184,11 +170,11 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 1
-        assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
+        assert any(p for p in files if search(r"^log\.1\__.+?\.txt$", p.name))
 
         await sleep(1)
         tmp_path.joinpath("log.txt").touch()
-        now = to_local_plain(get_now())
+        now = format_compact(get_now_local(), path=True)
         tmp_path.joinpath(f"log.99__{now}__{now}.txt").touch()
         actions = _compute_rollover_actions(tmp_path, "log", ".txt")
         assert len(actions.deletions) == 2
@@ -196,9 +182,7 @@ class TestComputeRolloverActions:
         actions.do()
         files = list(tmp_path.iterdir())
         assert len(files) == 1
-        assert any(
-            p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
-        )
+        assert any(p for p in files if search(r"^log\.1\__.+?__.+?\.txt$", p.name))
 
 
 class TestGetFormatStr:
@@ -278,7 +262,7 @@ class TestRotatingLogFile:
     def test_from_path_with_index_and_end(
         self, *, index: int, end: ZonedDateTime
     ) -> None:
-        path = Path(f"log.{index}__{to_local_plain(end)}.txt")
+        path = Path(f"log.{index}__{format_compact(end, path=True)}.txt")
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
@@ -294,7 +278,9 @@ class TestRotatingLogFile:
         self, *, index: int, datetimes: tuple[ZonedDateTime, ZonedDateTime]
     ) -> None:
         start, end = datetimes
-        path = Path(f"log.{index}__{to_local_plain(start)}__{to_local_plain(end)}.txt")
+        path = Path(
+            f"log.{index}__{format_compact(start, path=True)}__{format_compact(end, path=True)}.txt"
+        )
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
@@ -324,7 +310,9 @@ class TestRotatingLogFile:
         file = _RotatingLogFile(
             directory=root, stem="log", suffix=".txt", index=index, end=end
         )
-        assert file.path == root.joinpath(f"log.{index}__{to_local_plain(end)}.txt")
+        assert file.path == root.joinpath(
+            f"log.{index}__{format_compact(end, path=True)}.txt"
+        )
 
     @given(
         root=temp_paths(),
@@ -339,7 +327,7 @@ class TestRotatingLogFile:
             directory=root, stem="log", suffix=".txt", index=index, start=start, end=end
         )
         assert file.path == root.joinpath(
-            f"log.{index}__{to_local_plain(start)}__{to_local_plain(end)}.txt"
+            f"log.{index}__{format_compact(start, path=True)}__{format_compact(end, path=True)}.txt"
         )
 
 
@@ -393,46 +381,34 @@ class TestSizeAndTimeRotatingFileHandler:
                 assert any(p for p in files if search(r"^log\.txt$", p.name))
                 if cycle == 2:
                     assert any(
-                        p for p in files if search(r"^log\.1__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.1__.+?\.txt$", p.name)
                     )
                 elif cycle == 3:
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name)
                     )
                     assert any(
-                        p for p in files if search(r"^log\.2__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.2__.+?\.txt$", p.name)
                     )
                 elif cycle == 4:
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name)
                     )
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.2__.+?__.+?\.txt$", p.name)
                     )
                     assert any(
-                        p for p in files if search(r"^log\.3__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.3__.+?\.txt$", p.name)
                     )
                 elif cycle >= 5:
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name)
                     )
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.2__.+?__.+?\.txt$", p.name)
                     )
                     assert any(
-                        p
-                        for p in files
-                        if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
+                        p for p in files if search(r"^log\.3__.+?__.+?\.txt$", p.name)
                     )
                 await sleep(0.1)
 
@@ -463,7 +439,7 @@ class TestSizeAndTimeRotatingFileHandler:
             files = list(tmp_path.iterdir())
             assert len(files) == 2
             assert any(p for p in files if search(r"^log\.txt$", p.name))
-            assert any(p for p in files if search(r"^log\.1__[\dT]+\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.1__.+?\.txt$", p.name))
 
         await sleep(1.1)
         for i in range(4, 6):
@@ -471,10 +447,8 @@ class TestSizeAndTimeRotatingFileHandler:
             files = list(tmp_path.iterdir())
             assert len(files) == 3
             assert any(p for p in files if search(r"^log\.txt$", p.name))
-            assert any(
-                p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(p for p in files if search(r"^log\.2__[\dT]+\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.2__.+?\.txt$", p.name))
 
         await sleep(1.1)
         for i in range(6, 8):
@@ -482,13 +456,9 @@ class TestSizeAndTimeRotatingFileHandler:
             files = list(tmp_path.iterdir())
             assert len(files) == 4
             assert any(p for p in files if search(r"^log\.txt$", p.name))
-            assert any(
-                p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(
-                p for p in files if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(p for p in files if search(r"^log\.3__[\dT]+\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.2__.+?__.+?\.txt$", p.name))
+            assert any(p for p in files if search(r"^log\.3__.+?\.txt$", p.name))
 
         for _ in range(2):
             await sleep(1.1)
@@ -498,13 +468,13 @@ class TestSizeAndTimeRotatingFileHandler:
                 assert len(files) == 4
                 assert any(p for p in files if search(r"^log\.txt$", p.name))
                 assert any(
-                    p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                    p for p in files if search(r"^log\.1__.+?__.+?\.txt$", p.name)
                 )
                 assert any(
-                    p for p in files if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
+                    p for p in files if search(r"^log\.2__.+?__.+?\.txt$", p.name)
                 )
                 assert any(
-                    p for p in files if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
+                    p for p in files if search(r"^log\.3__.+?__.+?\.txt$", p.name)
                 )
 
     @mark.parametrize("max_bytes", [param(0), param(1)])
