@@ -3,8 +3,10 @@ from __future__ import annotations
 from re import escape
 from typing import TYPE_CHECKING, Any, Literal
 
+import numpy as np
 from hypothesis import assume, given
-from hypothesis.strategies import DataObject, data, floats, integers, none
+from hypothesis.extra.numpy import array_shapes
+from hypothesis.strategies import DataObject, data, floats, integers, none, sampled_from
 from numpy import (
     arange,
     array,
@@ -12,18 +14,22 @@ from numpy import (
     full,
     inf,
     isclose,
+    linspace,
     median,
     nan,
     ndarray,
     ones,
+    pi,
+    where,
     zeros,
     zeros_like,
 )
+from numpy.fft import fft, fftfreq
 from numpy.random import Generator
 from numpy.testing import assert_equal
 from pytest import mark, param, raises
 
-from utilities.hypothesis import float_arrays
+from utilities.hypothesis import float_arrays, pairs
 from utilities.numpy import (
     DEFAULT_RNG,
     AsIntError,
@@ -31,12 +37,21 @@ from utilities.numpy import (
     FlatN0MultipleError,
     NDArrayF,
     NDArrayI,
+    ShapeLike,
     ShiftError,
+    SigmoidError,
+    _BoxCarLocationsError,
+    _BoxCarLowerBoundSlopeError,
+    _BoxCarUpperBoundSlopeError,
+    adjust_frequencies,
     array_indexer,
     as_int,
+    bernoulli,
+    boxcar,
     discretize,
     fillna,
     flatn0,
+    get_frequency_spectrum,
     has_dtype,
     is_at_least,
     is_at_least_or_nan,
@@ -88,12 +103,39 @@ from utilities.numpy import (
     minimum,
     shift,
     shift_bool,
+    sigmoid,
 )
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
 
+class TestAdjustFrequencies:
+    def test_filter(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        noise = DEFAULT_RNG.normal(scale=0.25, size=n)
+        y = x + noise
+        result = adjust_frequencies(y, filters=lambda f: np.abs(f) <= 0.02)
+        assert result.shape == (n,)
+        amplitudes = fft(result)
+        freqs = fftfreq(n)
+        assert np.allclose(amplitudes[np.abs(freqs) > 0.02], 0.0)
+
+    def test_weight(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        noise = DEFAULT_RNG.normal(scale=0.25, size=n)
+        y = x + noise
+        result = adjust_frequencies(
+            y, weights=lambda f: where(np.abs(f) <= 0.02, 1.0, 0.0)
+        )
+        assert result.shape == (n,)
+        amplitudes = fft(result)
+        freqs = fftfreq(n)
+        assert np.allclose(amplitudes[np.abs(freqs) > 0.02], 0.0)
+
+
 class TestArrayIndexer:
     @mark.parametrize(
         ("i", "ndim", "expected"),
@@ -246,6 +288,65 @@ class TestDiscretize:
         assert_equal(result, expected)
 
 
+class TestBernoulli:
+    @given(case=sampled_from([(0.0, False), (1.0, True)]), size=array_shapes())
+    def test_main(self, *, case: tuple[float, bool], size: ShapeLike) -> None:
+        true, expected = case
+        result = bernoulli(true=true, size=size)
+        assert (result == expected).all()
+        assert result.shape == size
+
+
+class TestBoxCar:
+    @given(
+        locs=pairs(floats(-10.0, 10.0), sorted=True),
+        slope_low=floats(0.1, 10.0),
+        slope_high=floats(0.1, 10.0),
+    )
+    def test_main(
+        self, *, locs: tuple[float, float], slope_low: float, slope_high: float
+    ) -> None:
+        loc_low, loc_high = locs
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        y = boxcar(
+            x,
+            loc_low=loc_low,
+            slope_low=slope_low,
+            loc_high=loc_high,
+            slope_high=slope_high,
+        )
+        assert y.shape == (n,)
+        assert is_between(y, 0.0, 1.0).all()
+
+    def test_error_locations(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        with raises(
+            _BoxCarLocationsError,
+            match="Location parameters must be consistent; got 1.0 and -1.0",
+        ):
+            _ = boxcar(x, loc_low=1.0, loc_high=-1.0)
+
+    def test_error_lower_bound_slope(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        with raises(
+            _BoxCarLowerBoundSlopeError,
+            match="Lower-bound slope parameter must be positive; got 0.0",
+        ):
+            _ = boxcar(x, slope_low=0.0)
+
+    def test_error_upper_bound_slope(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        with raises(
+            _BoxCarUpperBoundSlopeError,
+            match="Upper-bound slope parameter must be positive; got 0.0",
+        ):
+            _ = boxcar(x, slope_high=0.0)
+
+
 class TestFillNa:
     @mark.parametrize(
         ("init", "value", "expected_v"),
@@ -288,6 +389,18 @@ class TestFlatN0:
             _ = flatn0(ones(2, dtype=bool))
 
 
+class TestGetFrequencySpectrum:
+    def test_main(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        noise = DEFAULT_RNG.normal(scale=0.25, size=n)
+        y = x + noise
+        y2 = adjust_frequencies(y, filters=lambda f: np.abs(f) <= 0.02)
+        result = get_frequency_spectrum(y2)
+        assert result.shape == (n, 2)
+        assert np.allclose(result[np.abs(result[:, 0]) > 0.02, 1], 0.0)
+
+
 class TestHasDtype:
     @mark.parametrize(("dtype", "expected"), [param(float, True), param(int, False)])
     @mark.parametrize("is_tuple", [param(True), param(False)])
@@ -1047,3 +1160,19 @@ class TestShiftBool:
             [fill_value if e is None else e for e in expected_v], dtype=bool
         )
         assert_equal(result, expected)
+
+
+class TestSigmoid:
+    @given(loc=floats(-10.0, 10.0), slope=floats(-10.0, -0.1) | floats(0.1, 10.0))
+    def test_main(self, *, loc: float, slope: float) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        y = sigmoid(x, loc=loc, slope=slope)
+        assert y.shape == (n,)
+        assert is_between(y, 0.0, 1.0).all()
+
+    def test_error(self) -> None:
+        n = 1000
+        x = linspace(0, 2 * pi, n)
+        with raises(SigmoidError, match="Slope must be non-zero"):
+            _ = sigmoid(x, slope=0.0)
