@@ -10,7 +10,7 @@ from sqlalchemy.orm import DeclarativeBase
 
 from utilities.asyncio import stream_command
 from utilities.iterables import always_iterable
-from utilities.logging import get_logger
+from utilities.logging import to_logger
 from utilities.os import temp_environ
 from utilities.pathlib import ensure_suffix
 from utilities.sqlalchemy import extract_url, get_table_name
@@ -21,7 +21,12 @@ if TYPE_CHECKING:
     from sqlalchemy import URL
 
     from utilities.sqlalchemy import TableOrORMInstOrClass
-    from utilities.types import LoggerOrName, MaybeListStr, MaybeSequence, PathLike
+    from utilities.types import (
+        LoggerLike,
+        MaybeCollection,
+        MaybeCollectionStr,
+        PathLike,
+    )
 
 
 type _PGDumpFormat = Literal["plain", "custom", "directory", "tar"]
@@ -37,19 +42,19 @@ async def pg_dump(
     data_only: bool = False,
     clean: bool = False,
     create: bool = False,
-    extension: MaybeListStr | None = None,
-    extension_exc: MaybeListStr | None = None,
-    schema: MaybeListStr | None = None,
-    schema_exc: MaybeListStr | None = None,
-    table: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
-    table_exc: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
+    extension: MaybeCollectionStr | None = None,
+    extension_exc: MaybeCollectionStr | None = None,
+    schema: MaybeCollectionStr | None = None,
+    schema_exc: MaybeCollectionStr | None = None,
+    table: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
+    table_exc: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
     inserts: bool = False,
     on_conflict_do_nothing: bool = False,
     role: str | None = None,
     docker: str | None = None,
     dry_run: bool = False,
-    logger: LoggerOrName | None = None,
-) -> None:
+    logger: LoggerLike | None = None,
+) -> bool:
     """Run `pg_dump`."""
     path = _path_pg_dump(path, format_=format_)
     path.parent.mkdir(parents=True, exist_ok=True)
@@ -74,33 +79,31 @@ async def pg_dump(
     )
     if dry_run:
         if logger is not None:
-            get_logger(logger=logger).info("Would run:\n\t%r", str(cmd))
-        return
+            to_logger(logger).info("Would run:\n\t%r", str(cmd))
+        return True
     with temp_environ(PGPASSWORD=url.password), Timer() as timer:  # pragma: no cover
         try:
             output = await stream_command(cmd)
         except KeyboardInterrupt:
             if logger is not None:
-                get_logger(logger=logger).info(
+                to_logger(logger).info(
                     "Cancelled backup to %r after %s", str(path), timer
                 )
             rmtree(path, ignore_errors=True)
-        else:
-            match output.return_code:
-                case 0:
-                    if logger is not None:
-                        get_logger(logger=logger).info(
-                            "Backup to %r finished after %s", str(path), timer
-                        )
-                case _:
-                    if logger is not None:
-                        get_logger(logger=logger).exception(
-                            "Backup to %r failed after %s\nstderr:\n%s",
-                            str(path),
-                            timer,
-                            output.stderr,
-                        )
-                    rmtree(path, ignore_errors=True)
+            return False
+        if output.return_code != 0:
+            if logger is not None:
+                to_logger(logger).exception(
+                    "Backup to %r failed after %s\nstderr:\n%s",
+                    str(path),
+                    timer,
+                    output.stderr,
+                )
+            rmtree(path, ignore_errors=True)
+            return False
+    if logger is not None:  # pragma: no cover
+        to_logger(logger).info("Backup to %r finished after %s", str(path), timer)
+    return True  # pragma: no cover
 
 
 def _build_pg_dump(
@@ -113,12 +116,12 @@ def _build_pg_dump(
     data_only: bool = False,
     clean: bool = False,
     create: bool = False,
-    extension: MaybeListStr | None = None,
-    extension_exc: MaybeListStr | None = None,
-    schema: MaybeListStr | None = None,
-    schema_exc: MaybeListStr | None = None,
-    table: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
-    table_exc: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
+    extension: MaybeCollectionStr | None = None,
+    extension_exc: MaybeCollectionStr | None = None,
+    schema: MaybeCollectionStr | None = None,
+    schema_exc: MaybeCollectionStr | None = None,
+    table: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
+    table_exc: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
     inserts: bool = False,
     on_conflict_do_nothing: bool = False,
     role: str | None = None,
@@ -185,7 +188,7 @@ def _path_pg_dump(path: PathLike, /, *, format_: _PGDumpFormat = "plain") -> Pat
             suffix = None
         case "tar":
             suffix = ".tar"
-        case _ as never:
+        case never:
             assert_never(never)
     path = Path(path)
     if suffix is not None:
@@ -206,14 +209,14 @@ async def restore(
     clean: bool = False,
     create: bool = False,
     jobs: int | None = None,
-    schema: MaybeListStr | None = None,
-    schema_exc: MaybeListStr | None = None,
-    table: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
+    schema: MaybeCollectionStr | None = None,
+    schema_exc: MaybeCollectionStr | None = None,
+    table: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
     role: str | None = None,
     docker: str | None = None,
     dry_run: bool = False,
-    logger: LoggerOrName | None = None,
-) -> None:
+    logger: LoggerLike | None = None,
+) -> bool:
     """Run `pg_restore`/`psql`."""
     cmd = _build_pg_restore_or_psql(
         url,
@@ -231,31 +234,29 @@ async def restore(
     )
     if dry_run:
         if logger is not None:
-            get_logger(logger=logger).info("Would run:\n\t%r", str(cmd))
-        return
+            to_logger(logger).info("Would run:\n\t%r", str(cmd))
+        return True
     with temp_environ(PGPASSWORD=url.password), Timer() as timer:  # pragma: no cover
         try:
             output = await stream_command(cmd)
         except KeyboardInterrupt:
             if logger is not None:
-                get_logger(logger=logger).info(
+                to_logger(logger).info(
                     "Cancelled restore from %r after %s", str(path), timer
                 )
-        else:
-            match output.return_code:
-                case 0:
-                    if logger is not None:
-                        get_logger(logger=logger).info(
-                            "Restore from %r finished after %s", str(path), timer
-                        )
-                case _:
-                    if logger is not None:
-                        get_logger(logger=logger).exception(
-                            "Restore from %r failed after %s\nstderr:\n%s",
-                            str(path),
-                            timer,
-                            output.stderr,
-                        )
+            return False
+        if output.return_code != 0:
+            if logger is not None:
+                to_logger(logger).exception(
+                    "Restore from %r failed after %s\nstderr:\n%s",
+                    str(path),
+                    timer,
+                    output.stderr,
+                )
+            return False
+    if logger is not None:  # pragma: no cover
+        to_logger(logger).info("Restore from %r finished after %s", str(path), timer)
+    return True  # pragma: no cover
 
 
 ##
@@ -271,9 +272,9 @@ def _build_pg_restore_or_psql(
     clean: bool = False,
     create: bool = False,
     jobs: int | None = None,
-    schema: MaybeListStr | None = None,
-    schema_exc: MaybeListStr | None = None,
-    table: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
+    schema: MaybeCollectionStr | None = None,
+    schema_exc: MaybeCollectionStr | None = None,
+    table: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
     role: str | None = None,
     docker: str | None = None,
 ) -> str:
@@ -304,9 +305,9 @@ def _build_pg_restore(
     clean: bool = False,
     create: bool = False,
     jobs: int | None = None,
-    schemas: MaybeListStr | None = None,
-    schemas_exc: MaybeListStr | None = None,
-    tables: MaybeSequence[TableOrORMInstOrClass | str] | None = None,
+    schemas: MaybeCollectionStr | None = None,
+    schemas_exc: MaybeCollectionStr | None = None,
+    tables: MaybeCollection[TableOrORMInstOrClass | str] | None = None,
     role: str | None = None,
     docker: str | None = None,
 ) -> str:
@@ -374,7 +375,7 @@ def _get_table_name(obj: TableOrORMInstOrClass | str, /) -> str:
             return get_table_name(table_or_orm)
         case str() as name:
             return name
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -390,7 +391,7 @@ def _resolve_data_only_and_clean(
             return ["--clean", "--if-exists"]
         case True, True:
             raise _ResolveDataOnlyAndCleanError
-        case _ as never:
+        case never:
             assert_never(never)
 
 
